import { Component } from '@angular/core';
import { AlertController } from '@ionic/angular';
import { CloudObject, CloudQuery, CloudUser } from 'src/lib/ncloud';
//import { CloudObject ,CloudQuery} from './CloudObject'; // 假设这些文件在同一目录下


@Component({
  selector: 'app-tab2',
  templateUrl: 'tab2.page.html',
  styleUrls: ['tab2.page.scss'],
  standalone: false,
})
export class Tab2Page {
  // 社交圈列表数据
  socialCircles: any[] = [];
  // 当前用户
  currentUser: CloudUser | null = null;

  constructor(private alertController: AlertController) {
    // 初始化时加载社交圈列表
    this.loadSocialCircles();
    // 初始化当前用户
    this.initCurrentUser();
  }

  // 初始化当前用户
  async initCurrentUser() {
    this.currentUser = new CloudUser();
    if (this.currentUser.sessionToken) {
      // 用户已登录，可以获取当前用户信息
      const user = await this.currentUser.current();
      if (user) {
        console.log('当前用户:', user);
      }
    }
  }

  // 打开AI助手
  async openAIAssistant() {
    const alert = await this.alertController.create({
      header: 'AI旅行助手',
      message: '请告诉我您想了解的旅行信息或需求',
      inputs: [
        {
          name: 'question',
          type: 'text',
          placeholder: '例如：推荐北京的必去景点'
        }
      ],
      buttons: [
        {
          text: '取消',
          role: 'cancel'
        },
        {
          text: '发送',
          handler: (data) => {
            if (data.question) {
              this.simulateAIResponse(data.question);
            }
          }
        }
      ]
    });

    await alert.present();
  }

  // 模拟AI回复
  private simulateAIResponse(question: string) {
    console.log('用户问题:', question);
    // 这里应该是调用AI服务的实际代码
    setTimeout(() => {
      this.showAIResponse('根据您的需求，推荐以下景点：故宫、颐和园、798艺术区');
    }, 1000);
  }

  // 显示AI回复
  private async showAIResponse(message: string) {
    const alert = await this.alertController.create({
      header: 'AI回复',
      message: message,
      buttons: ['好的']
    });
    await alert.present();
  }

  // 打开社交圈子
  openSocialCircle() {
    console.log('打开社交圈子页面');
    this.showAlert('功能提示', '即将打开旅行社交圈功能');
  }

  // 创建新帖子
  async createNewPost() {
    const alert = await this.alertController.create({
      header: '分享旅行故事',
      inputs: [
        {
          name: 'content',
          type: 'textarea',
          placeholder: '写下你的旅行见闻...'
        }
      ],
      buttons: [
        {
          text: '取消',
          role: 'cancel'
        },
        {
          text: '发布',
          handler: (data) => {
            if (data.content) {
              this.showAlert('发布成功', '您的分享已发布到社交圈');
            }
          }
        }
      ]
    });

    await alert.present();
  }

  // 创建新的社交圈
  async createSocialCircle() {
    const alert = await this.alertController.create({
      header: '创建旅行社交圈',
      inputs: [
        {
          name: 'name',
          type: 'text',
          placeholder: '社交圈名称'
        },
        {
          name: 'description',
          type: 'textarea',
          placeholder: '社交圈描述'
        }
      ],
      buttons: [
        {
          text: '取消',
          role: 'cancel'
        },
        {
          text: '创建',
          handler: async (data) => {
            if (data.name && data.description) {
              try {
                // 检查用户是否登录
                if (!this.currentUser || !this.currentUser.sessionToken) {
                  this.showAlert('提示', '请先登录后再创建社交圈');
                  return;
                }

                // 创建社交圈对象
                const socialCircle = new CloudObject('SocialCircle');
                socialCircle.set({
                  name: data.name,
                  description: data.description,
                  createdBy: this.currentUser.toPointer(), // 使用指针关联创建者
                  createdAt: new Date().toISOString()
                });

                // 保存社交圈
                await socialCircle.save();
                
                // 刷新社交圈列表
                this.loadSocialCircles();
                
                this.showAlert('成功', '社交圈创建成功！');
              } catch (error) {
                console.error('创建社交圈失败:', error);
                this.showAlert('错误', '创建社交圈失败，请重试');
              }
            } else {
              this.showAlert('提示', '请填写社交圈名称和描述');
            }
          }
        }
      ]
    });

    await alert.present();
  }

  // 加载社交圈列表
  async loadSocialCircles() {
    try {
      const query = new CloudQuery('SocialCircle');
      // 可以添加排序，比如按创建时间倒序
      // query.queryParams.order = '-createdAt';
      
      this.socialCircles = await query.find();
      console.log('加载的社交圈:', this.socialCircles);
    } catch (error) {
      console.error('加载社交圈失败:', error);
      this.showAlert('错误', '加载社交圈失败，请重试');
    }
  }

  // 将静态数据对象数组保存到后端
  async saveStaticDataToCloud() {
    // 示例静态数据数组
    const staticDataArray = [
      { name: '国内游', description: '国内旅游景点推荐' },
      { name: '国外游', description: '国外旅游景点推荐' },
      { name: '美食探店', description: '各地美食推荐' }
    ];

    try {
      // 确保用户已登录
      if (!this.currentUser || !this.currentUser.sessionToken) {
        this.showAlert('提示', '请先登录后再保存数据');
        return;
      }

      // 创建并保存每个静态数据对象
      for (const item of staticDataArray) {
        const category = new CloudObject('TravelCategory');
        category.set({
          name: item.name,
          description: item.description,
          createdBy: this.currentUser.toPointer(),
          createdAt: new Date().toISOString()
        });
        
        await category.save();
      }

      // 重新加载数据
      await this.loadSocialCircles(); // 或者如果是不同的数据类型，创建一个新的查询方法
      
      this.showAlert('成功', '静态数据已成功保存到云端');
    } catch (error) {
      console.error('保存静态数据失败:', error);
      this.showAlert('错误', '保存静态数据失败，请重试');
    }
  }

  // 从后端加载静态数据并显示
  async loadStaticDataFromCloud() {
    try {
      // 假设静态数据存储在'TravelCategory'类中
      const query = new CloudQuery('TravelCategory');
      // 可以添加排序
      // query.queryParams.order = '-createdAt';
      
      const data = await query.find();
      console.log('加载的静态数据:', data);
      
      // 这里可以根据需要处理数据，比如显示在页面上
      // 由于当前页面没有显示这部分数据的UI，可以暂时只打印日志
    } catch (error) {
      console.error('加载静态数据失败:', error);
      this.showAlert('错误', '加载静态数据失败，请重试');
    }
  }

  // 通用提示框
  private async showAlert(header: string, message: string) {
    const alert = await this.alertController.create({
      header,
      message,
      buttons: ['好的']
    });
    await alert.present();
  }
}